agentle.agents.agent\_config\_dict
==================================

.. automodule:: agentle.agents.agent_config_dict

   
   .. rubric:: Functions

   .. autosummary::
   
      TypedDict
   
   .. rubric:: Classes

   .. autosummary::
   
      AgentConfigDict
      GenerationConfig
      GenerationConfigDict
   